/***************************************************************************//**
 *   @file   Main.c
 *   @brief  Implementation of the program's main function.
 *   @author DNechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 559
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRL78G13.h"        // YRDKRL78G13 definitions.
#include "ST7579.h"				// ST7579 definitions.
#include "ADN2850.h"            // ADN2850 definitions.

/******************************************************************************/
/* Option Bytes                                                               */
/******************************************************************************/
#pragma location = "OPTBYTE"
__root const uint8_t opbyte0 = 0x00U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte1 = 0xFFU;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte2 = 0xE8U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte3 = 0x04U;

/******************************************************************************/
/* Security ID                                                                */
/******************************************************************************/
#pragma location = "SECUID"
__root const uint8_t secuid[10] = 
    {0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U};

/******************************************************************************/
/* Variables Declarations                                                     */
/******************************************************************************/
const unsigned char adiLogo [2 * 19] =
	{ 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x07, 0x07,
	  0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7F, 0x7F,
	  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xC0,
	  0xC0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF8, 0xF8, 0xFC,
	  0xFC, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF };	// ADI Logo.
unsigned long result = 0x0;

/***************************************************************************//**
 * @brief Creates a delay of miliseconds.
 *
 * @param mSeconds - time in miliseconds.
 *
 * @return None.
*******************************************************************************/
void DelayMs(unsigned long mSeconds)
{
    unsigned long time = 0;
    
    R_TAU0_Channel0_Start();
    while(time < mSeconds)
    {
        if(TMIF00 == 1)
        {
            time++;
            TMIF00 = 0;
        }
    }
    R_TAU0_Channel0_Stop();
}

/***************************************************************************//**
 * @brief Main function.
 *
 * @param None.
 *
 * @return None.
*******************************************************************************/
void  main(void)
{    
    unsigned long receiveData    = 0x0;
    unsigned short intNumber     = 0x0;
    float decimalNumber = 0x0;
    
    YRDKRL78G13_Init();
    ST7579_Init();
    ST7579_Image(2, 0, adiLogo, 19, 16);
    ST7579_String(2, 21, "ANALOG");
    ST7579_String(3, 21, "DEVICES");
    ST7579_String(4, 0, "wiki.analog.com");
    DelayMs(2000);
    ST7579_Clear();
    ST7579_Image(0,0,adiLogo,19,16);	
    ST7579_String(0,22,"ST7579 OK");
    //Select MUX A0 = 1; A1 = 0; A2 = 1; => Selects SYNC-6;
    PM5 &= ~((1 << 2) | (1 << 3) | (1 << 4));
    P5  |= (1 << 2) | (0 << 3) | (1 << 4);  
    // Initializes communication.
    if(ADN2850_Init())
    {
         ST7579_String(1,22,"ADN2850 OK");
    }
    else
    {
         ST7579_String(1,22,"ADN2850 Err");
    }
    // Reads RDAC1 tolerance.
    receiveData = ADN2850_Read(ADN2850_READ_EEM_CMD, ADN2850_RWB1_TOLERANCE); 
    // Display tolerance in floating point format.
    ST7579_String(3, 0, "Tolerance[%]:");
    receiveData -=0x8000;
    if(receiveData > 0)
    {
        ST7579_String(4, 0, "+");
    }
    else
    {
        ST7579_String(4, 0, "-");
    }
    intNumber = (unsigned char)(receiveData >> 8);
    decimalNumber = (receiveData & 0x00FF) * 1000 /256;
    ST7579_Number(4, 12, intNumber, 2);
    ST7579_String(4, 18, ".");
    ST7579_Number(4, 36, (unsigned short)decimalNumber, 3);
    // Writes 0x0200 to RDAC1
    ADN2850_SendCommand(ADN2850_WRITE_RDAC_CMD, 
                       ADN2850_RDAC1,
                       0x0200);
    // Increments resistance value with 24.4 Ohms.
    ADN2850_SendCommand(ADN2850_INCREMENT_1STEP_CMD, 
                       ADN2850_RDAC1,
                       0);
    // Performs another increment.
    ADN2850_RepeatLastCMD();
    // Reads data form RDAC1 register.
    receiveData = ADN2850_Read(ADN2850_READ_RDAC_CMD, ADN2850_RDAC1);
    // Displays data form RDAC1 register.
    ST7579_String(5, 0, "RDAC1[Ohm]:");
    ST7579_Number(6, 24, ADN2850_OhmConversion(receiveData), 5);
    while(1)
    {
        ;
    }
}

